svn commit: r327239 - head/sys/cam/ctl

2017-12-27 Thread Emmanuel Vadot
Author: manu
Date: Wed Dec 27 15:39:31 2017
New Revision: 327239
URL: https://svnweb.freebsd.org/changeset/base/327239

Log:
  ctl: Correct comment in ctl_worker_thread
  
  The incoming queue is handled before the RtR one.
  No functional change.
  
  MFC after:3 days

Modified:
  head/sys/cam/ctl/ctl.c

Modified: head/sys/cam/ctl/ctl.c
==
--- head/sys/cam/ctl/ctl.c  Wed Dec 27 14:50:07 2017(r327238)
+++ head/sys/cam/ctl/ctl.c  Wed Dec 27 15:39:31 2017(r327239)
@@ -13352,8 +13352,8 @@ ctl_work_thread(void *arg)
 * We handle the queues in this order:
 * - ISC
 * - done queue (to free up resources, unblock other commands)
-* - RtR queue
 * - incoming queue
+* - RtR queue
 *
 * If those queues are empty, we break out of the loop and
 * go to sleep.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327240 - head/sys/arm/allwinner

2017-12-27 Thread Kyle Evans
Author: kevans
Date: Wed Dec 27 18:22:02 2017
New Revision: 327240
URL: https://svnweb.freebsd.org/changeset/base/327240

Log:
  if_awg: Respect rgmii-*id PHY configurations
  
  phy-mode can be one of: rgmii, rgmii-id, rgmii-txid, rgmii-rxid; as this was
  written, any of these alternate -id configurations would break as we fail to
  configure syscon for rgmii. Instead, simply check that phy-mode is
  configured for rgmii and we'll let the PHY driver handle any internal delay
  configuration.
  
  The pine64 should eventually specify phy-mode = "rgmii-txid" to address
  gigabit issues when rx delay is configured, motivating this change.

Modified:
  head/sys/arm/allwinner/if_awg.c

Modified: head/sys/arm/allwinner/if_awg.c
==
--- head/sys/arm/allwinner/if_awg.c Wed Dec 27 15:39:31 2017
(r327239)
+++ head/sys/arm/allwinner/if_awg.c Wed Dec 27 18:22:02 2017
(r327240)
@@ -1177,7 +1177,7 @@ awg_setup_phy(device_t dev)
if (sc->res[_RES_SYSCON] != NULL) {
reg = bus_read_4(sc->res[_RES_SYSCON], 0);
reg &= ~(EMAC_CLK_PIT | EMAC_CLK_SRC | EMAC_CLK_RMII_EN);
-   if (strcmp(phy_type, "rgmii") == 0)
+   if (strncmp(phy_type, "rgmii", 5) == 0)
reg |= EMAC_CLK_PIT_RGMII | EMAC_CLK_SRC_RGMII;
else if (strcmp(phy_type, "rmii") == 0)
reg |= EMAC_CLK_RMII_EN;
@@ -1217,7 +1217,7 @@ awg_setup_phy(device_t dev)
device_printf(dev, "EMAC clock: 0x%08x\n", reg);
bus_write_4(sc->res[_RES_SYSCON], 0, reg);
} else {
-   if (strcmp(phy_type, "rgmii") == 0)
+   if (strncmp(phy_type, "rgmii", 5) == 0)
tx_parent_name = "emac_int_tx";
else
tx_parent_name = "mii_phy_tx";
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327241 - head/usr.sbin/devmatch

2017-12-27 Thread Warner Losh
Author: imp
Date: Wed Dec 27 18:30:24 2017
New Revision: 327241
URL: https://svnweb.freebsd.org/changeset/base/327241

Log:
  Fix a bunch of issues (and a few non-issues but appeasement is easier
  than arguing) Coverity found:
  
  o Use open + fstat rather than stat + open to avoid any races for a
file that's static for the life of the system. This will prevent any
problems should someone insert a new device while installing a
kernel in the future.
  o Use strlcpy instead of strcpy as a failsafe to knowing that the
strings can't possibly be larger than the buffer due to data
source limits (though in the future these limits might be more
dynamic).
  o If we can't find the hints file, return rather than dereference
a NULL pointer.
  o Check for lastmod before calling strcmp in case a PNP entry
comes before a module entry. That's not allowed, but within the
realm of crazy things programmers do.
  o Free lastmod before exiting search_hints() to avoid a leak.
  
  CID: 1383971, 1383970, 1383969, 1383965, 1383963, 1383960

Modified:
  head/usr.sbin/devmatch/devmatch.c

Modified: head/usr.sbin/devmatch/devmatch.c
==
--- head/usr.sbin/devmatch/devmatch.c   Wed Dec 27 18:22:02 2017
(r327240)
+++ head/usr.sbin/devmatch/devmatch.c   Wed Dec 27 18:30:24 2017
(r327241)
@@ -31,6 +31,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -78,14 +79,17 @@ read_linker_hints(void)
p = modpath;
while ((q = strsep(&p, ";")) != NULL) {
snprintf(fn, sizeof(fn), "%s/linker.hints", q);
-   if (stat(fn, &sb) != 0)
-   continue;
+   fd = open(fn, O_RDONLY);
+   if (fd < 0) {
+   if (errno == ENOENT)
+   continue;
+   err(1, "Can't open %s for reading", fn);
+   }
+   if (fstat(fd, &sb) != 0)
+   err(1, "Can't fstat %s\n", fn);
hints = malloc(sb.st_size);
if (hints == NULL)
err(1, "not enough space to read hints file of %ju 
bytes", (uintmax_t)sb.st_size);
-   fd = open(fn, O_RDONLY);
-   if (fd < 0)
-   err(1, "Can't open %s for reading", fn);
if (read(fd, hints, sb.st_size) != sb.st_size)
err(1, "Can't read in %ju bytes from %s", 
(uintmax_t)sb.st_size, fn);
close(fd);
@@ -95,6 +99,7 @@ read_linker_hints(void)
warnx("Can't read linker hints file.");
free(hints);
hints = NULL;
+   return;
}
if (*(int *)(intptr_t)hints != LINKER_HINTS_VERSION) {
warnx("Linker hints version %d doesn't match expected %d.",
@@ -144,12 +149,12 @@ pnpval_as_int(const char *val, const char *pnpinfo)
cp = strchr(val, ';');
key[0] = ' ';
if (cp == NULL)
-   strcpy(key + 1, val);
+   strlcpy(key + 1, val, sizeof(key) - 1);
else {
memcpy(key + 1, val, cp - val);
key[cp - val + 1] = '\0';
}
-   strcat(key, "=");
+   strlcat(key, "=", sizeof(key));
if (strncmp(key + 1, pnpinfo, strlen(key + 1)) == 0)
rv = strtol(pnpinfo + strlen(key + 1), NULL, 0);
else {
@@ -241,7 +246,7 @@ search_hints(const char *bus, const char *dev, const c
printf("Module %s in %s\n", val1, val2);
break;
case MDT_PNP_INFO:
-   if (!dump_flag && !unbound_flag && strcmp(lastmod, 
"kernel") == 0)
+   if (!dump_flag && !unbound_flag && lastmod && 
strcmp(lastmod, "kernel") == 0)
break;
getstr(&ptr, val1);
getstr(&ptr, val2);
@@ -343,6 +348,7 @@ search_hints(const char *bus, const char *dev, const c
printf(" -");
printf("\n");
}
+   free(lastmod);
 }
 
 static int
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327242 - head/sys/net

2017-12-27 Thread Stephen Hurd
Author: shurd
Date: Wed Dec 27 19:12:32 2017
New Revision: 327242
URL: https://svnweb.freebsd.org/changeset/base/327242

Log:
  Fix indentation.
  
  Sponsored by: Limelight Networks

Modified:
  head/sys/net/iflib.c

Modified: head/sys/net/iflib.c
==
--- head/sys/net/iflib.cWed Dec 27 18:30:24 2017(r327241)
+++ head/sys/net/iflib.cWed Dec 27 19:12:32 2017(r327242)
@@ -2635,7 +2635,7 @@ iflib_rxeof(iflib_rxq_t rxq, qidx_t budget)
if ((m->m_pkthdr.csum_flags & 
(CSUM_L4_CALC|CSUM_L4_VALID)) ==
(CSUM_L4_CALC|CSUM_L4_VALID)) {
if (lro_possible && tcp_lro_rx(&rxq->ifr_lc, m, 
0) == 0)
-   continue;
+   continue;
}
}
 #endif
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327243 - in head/sys/ufs: ffs ufs

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 19:13:50 2017
New Revision: 327243
URL: https://svnweb.freebsd.org/changeset/base/327243

Log:
  SPDX: Complete License ID tags for UFS.

Modified:
  head/sys/ufs/ffs/ffs_alloc.c
  head/sys/ufs/ffs/ffs_balloc.c
  head/sys/ufs/ffs/ffs_vnops.c
  head/sys/ufs/ufs/dinode.h

Modified: head/sys/ufs/ffs/ffs_alloc.c
==
--- head/sys/ufs/ffs/ffs_alloc.cWed Dec 27 19:12:32 2017
(r327242)
+++ head/sys/ufs/ffs/ffs_alloc.cWed Dec 27 19:13:50 2017
(r327243)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2002 Networks Associates Technology, Inc.
  * All rights reserved.

Modified: head/sys/ufs/ffs/ffs_balloc.c
==
--- head/sys/ufs/ffs/ffs_balloc.c   Wed Dec 27 19:12:32 2017
(r327242)
+++ head/sys/ufs/ffs/ffs_balloc.c   Wed Dec 27 19:13:50 2017
(r327243)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2002 Networks Associates Technology, Inc.
  * All rights reserved.

Modified: head/sys/ufs/ffs/ffs_vnops.c
==
--- head/sys/ufs/ffs/ffs_vnops.cWed Dec 27 19:12:32 2017
(r327242)
+++ head/sys/ufs/ffs/ffs_vnops.cWed Dec 27 19:13:50 2017
(r327243)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2002, 2003 Networks Associates Technology, Inc.
  * All rights reserved.

Modified: head/sys/ufs/ufs/dinode.h
==
--- head/sys/ufs/ufs/dinode.h   Wed Dec 27 19:12:32 2017(r327242)
+++ head/sys/ufs/ufs/dinode.h   Wed Dec 27 19:13:50 2017(r327243)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2002 Networks Associates Technology, Inc.
  * All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327244 - head/sys/net

2017-12-27 Thread Stephen Hurd
Author: shurd
Date: Wed Dec 27 19:14:15 2017
New Revision: 327244
URL: https://svnweb.freebsd.org/changeset/base/327244

Log:
  Remove assertion that's not true for !EARLY_AP_STARTUP
  
  gtask->gt_taskqueue is NULL when EARLY_AP_STARTUP is not enabled.
  Remove assertion to allow this config to work.
  
  Reported by:  oleg
  Sponsored by: Limelight Networks

Modified:
  head/sys/net/iflib.c

Modified: head/sys/net/iflib.c
==
--- head/sys/net/iflib.cWed Dec 27 19:13:50 2017(r327243)
+++ head/sys/net/iflib.cWed Dec 27 19:14:15 2017(r327244)
@@ -5174,7 +5174,6 @@ iflib_irq_set_affinity(if_ctx_t ctx, int irq, iflib_in
if (cpuid > ctx->ifc_cpuid_highest)
ctx->ifc_cpuid_highest = cpuid;
 #endif
-   MPASS(gtask->gt_taskqueue != NULL);
return 0;
 }
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r327013 - head/sys/net

2017-12-27 Thread shurd



On Sun, 24 Dec 2017 12:43:29 +0300, Oleg Bulyzhin  wrote:

  On Sat, Dec 23, 2017 at 11:13:37PM -0500, Stephen Hurd wrote:


Hrm, can you try it with:
options EARLY_AP_STARTUP

In slave-amd64-smp-debug?


yes, it does boot now:

 
Should be fixed for !EARLY_AP_STARTUP as of r327244.  Thanks for the report. 


___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327245 - head/sbin/ccdconfig

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 20:09:50 2017
New Revision: 327245
URL: https://svnweb.freebsd.org/changeset/base/327245

Log:
  ccdconfig: Update licensing terms.
  
  The code originate in NetBSD and there are the copyright notes have been
  assigned to the NetBSD Foundation. Update the files up to the point where
  we started diverging.
  
  Further relaxation of the licensing terms are possible after we
  check the NetBSD updates, and contact the local authors.
  
  In the case of ccdconfig.8 this reinstates the 3rd clause but since the
  code is not directly from Berkeley, the change was bogus.
  
  Obtained from:NetBSD

Modified:
  head/sbin/ccdconfig/ccdconfig.8
  head/sbin/ccdconfig/ccdconfig.c
  head/sbin/ccdconfig/pathnames.h

Modified: head/sbin/ccdconfig/ccdconfig.8
==
--- head/sbin/ccdconfig/ccdconfig.8 Wed Dec 27 19:14:15 2017
(r327244)
+++ head/sbin/ccdconfig/ccdconfig.8 Wed Dec 27 20:09:50 2017
(r327245)
@@ -1,8 +1,11 @@
-.\"$NetBSD: ccdconfig.8,v 1.1.2.1 1995/11/11 02:43:33 thorpej Exp $
+.\"$NetBSD: ccdconfig.8,v 1.4 1996/02/28 01:01:17 thorpej Exp $
 .\"
-.\" Copyright (c) 1995 Jason R. Thorpe.
+.\" Copyright (c) 1996 The NetBSD Foundation, Inc.
 .\" All rights reserved.
 .\"
+.\" This code is derived from software contributed to The NetBSD Foundation
+.\" by Jason R. Thorpe.
+.\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
 .\" are met:
@@ -11,8 +14,13 @@
 .\" 2. Redistributions in binary form must reproduce the above copyright
 .\"notice, this list of conditions and the following disclaimer in the
 .\"documentation and/or other materials provided with the distribution.
-.\" 4. The name of the author may not be used to endorse or promote products
-.\"derived from this software without specific prior written permission.
+.\" 3. All advertising materials mentioning features or use of this software
+.\"must display the following acknowledgement:
+.\"This product includes software developed by the NetBSD
+.\"Foundation, Inc. and its contributors.
+.\" 4. Neither the name of The NetBSD Foundation nor the names of its
+.\"contributors may be used to endorse or promote products derived
+.\"from this software without specific prior written permission.
 .\"
 .\" THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 .\" IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES

Modified: head/sbin/ccdconfig/ccdconfig.c
==
--- head/sbin/ccdconfig/ccdconfig.c Wed Dec 27 19:14:15 2017
(r327244)
+++ head/sbin/ccdconfig/ccdconfig.c Wed Dec 27 20:09:50 2017
(r327245)
@@ -1,10 +1,15 @@
+/* $NetBSD: ccdconfig.c,v 1.6 1996/05/16 07:11:18 thorpej Exp $*/
+
 /*-
  * SPDX-License-Identifier: BSD-4-Clause
  *
  * Copyright (c) 2003 Poul-Henning Kamp
- * Copyright (c) 1995 Jason R. Thorpe.
+ * Copyright (c) 1996 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
+ * This code is derived from software contributed to The NetBSD Foundation
+ * by Jason R. Thorpe.
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -15,22 +20,23 @@
  *documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *must display the following acknowledgement:
- * This product includes software developed for the NetBSD Project
- * by Jason R. Thorpe.
- * 4. The name of the author may not be used to endorse or promote products
- *derived from this software without specific prior written permission.
+ *This product includes software developed by the NetBSD
+ *Foundation, Inc. and its contributors.
+ * 4. Neither the name of The NetBSD Foundation nor the names of its
+ *contributors may be used to endorse or promote products derived
+ *from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBIL

svn commit: r327246 - head/usr.sbin/devmatch

2017-12-27 Thread Warner Losh
Author: imp
Date: Wed Dec 27 20:33:37 2017
New Revision: 327246
URL: https://svnweb.freebsd.org/changeset/base/327246

Log:
  Use strl* here too.
  
  CID: 1383969

Modified:
  head/usr.sbin/devmatch/devmatch.c

Modified: head/usr.sbin/devmatch/devmatch.c
==
--- head/usr.sbin/devmatch/devmatch.c   Wed Dec 27 20:09:50 2017
(r327245)
+++ head/usr.sbin/devmatch/devmatch.c   Wed Dec 27 20:33:37 2017
(r327246)
@@ -195,12 +195,12 @@ pnpval_as_str(const char *val, const char *pnpinfo)
cp = strchr(val, ';');
key[0] = ' ';
if (cp == NULL)
-   strcpy(key + 1, val);
+   strlcpy(key + 1, val, sizeof(key) - 1);
else {
memcpy(key + 1, val, cp - val);
key[cp - val + 1] = '\0';
}
-   strcat(key, "=");
+   strlcat(key, "=", sizeof(key));
if (strncmp(key + 1, pnpinfo, strlen(key + 1)) == 0)
quoted_strcpy(retval, pnpinfo + strlen(key + 1));
else {
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327247 - head/sys/net

2017-12-27 Thread Stephen Hurd
Author: shurd
Date: Wed Dec 27 20:42:30 2017
New Revision: 327247
URL: https://svnweb.freebsd.org/changeset/base/327247

Log:
  Don't pass rids to taskqgroup_attach()
  
  As everywhere else, we want to pass rman_get_start(irq->ii_res).  This
  caused set affinity errors when not using MSI-X vectors (legacy and MSI
  interrupts).
  
  Reported by:  sbruno
  Sponsored by: Limelight Networks

Modified:
  head/sys/net/iflib.c

Modified: head/sys/net/iflib.c
==
--- head/sys/net/iflib.cWed Dec 27 20:33:37 2017(r327246)
+++ head/sys/net/iflib.cWed Dec 27 20:42:30 2017(r327247)
@@ -5347,10 +5347,10 @@ iflib_legacy_setup(if_ctx_t ctx, driver_filter_t filte
if ((err = _iflib_irq_alloc(ctx, irq, tqrid, iflib_fast_intr_ctx, NULL, 
info, name)) != 0)
return (err);
GROUPTASK_INIT(gtask, 0, fn, q);
-   taskqgroup_attach(tqg, gtask, q, tqrid, name);
+   taskqgroup_attach(tqg, gtask, q, rman_get_start(irq->ii_res), name);
 
GROUPTASK_INIT(&txq->ift_task, 0, _task_fn_tx, txq);
-   taskqgroup_attach(qgroup_if_io_tqg, &txq->ift_task, txq, tqrid, "tx");
+   taskqgroup_attach(qgroup_if_io_tqg, &txq->ift_task, txq, 
rman_get_start(irq->ii_res), "tx");
return (0);
 }
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327248 - in head/lib/libc: locale mips

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 21:21:03 2017
New Revision: 327248
URL: https://svnweb.freebsd.org/changeset/base/327248

Log:
  SPDX: Fix some License ID tags for libc.

Modified:
  head/lib/libc/locale/euc.c
  head/lib/libc/mips/SYS.h

Modified: head/lib/libc/locale/euc.c
==
--- head/lib/libc/locale/euc.c  Wed Dec 27 20:42:30 2017(r327247)
+++ head/lib/libc/locale/euc.c  Wed Dec 27 21:21:03 2017(r327248)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Copyright 2013 Garrett D'Amore 
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.

Modified: head/lib/libc/mips/SYS.h
==
--- head/lib/libc/mips/SYS.hWed Dec 27 20:42:30 2017(r327247)
+++ head/lib/libc/mips/SYS.hWed Dec 27 21:21:03 2017(r327248)
@@ -2,7 +2,7 @@
 /* $FreeBSD$ */
 
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: (BSD-4-Clause AND BSD-3-Clause)
  *
  * Copyright (c) 1996 Jonathan Stone
  * All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327249 - head/lib/libcam

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 21:36:37 2017
New Revision: 327249
URL: https://svnweb.freebsd.org/changeset/base/327249

Log:
  SPDX: Small for a license ID tags.
  
  Use parenthesis for grouping as suggested by the spec.

Modified:
  head/lib/libcam/camlib.h

Modified: head/lib/libcam/camlib.h
==
--- head/lib/libcam/camlib.hWed Dec 27 21:21:03 2017(r327248)
+++ head/lib/libcam/camlib.hWed Dec 27 21:36:37 2017(r327249)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause AND BSD-2-Clause-FreeBSD
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-4-Clause) 
  *
  * Copyright (c) 1997, 1998 Kenneth D. Merry.
  * All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327250 - in head/sys: arm/allwinner arm/altera/socfpga arm/amlogic/aml8726 arm/annapurna/alpine arm/broadcom/bcm2835 arm/freescale/imx arm/freescale/vybrid arm/lpc arm/mv arm/nvidia/te...

2017-12-27 Thread Emmanuel Vadot
Author: manu
Date: Wed Dec 27 21:39:57 2017
New Revision: 327250
URL: https://svnweb.freebsd.org/changeset/base/327250

Log:
  arm: Add kern/kern_clocksource.c to files.arm
  
  Instead of adding it to every files.vendor, add it to the common arch file.

Modified:
  head/sys/arm/allwinner/files.allwinner
  head/sys/arm/altera/socfpga/files.socfpga
  head/sys/arm/amlogic/aml8726/files.aml8726
  head/sys/arm/annapurna/alpine/files.alpine
  head/sys/arm/broadcom/bcm2835/files.bcm283x
  head/sys/arm/freescale/imx/files.imx5
  head/sys/arm/freescale/imx/files.imx6
  head/sys/arm/freescale/vybrid/files.vybrid
  head/sys/arm/lpc/files.lpc
  head/sys/arm/mv/files.mv
  head/sys/arm/nvidia/tegra124/files.tegra124
  head/sys/arm/qemu/files.qemu
  head/sys/arm/ralink/files.ralink
  head/sys/arm/rockchip/files.rk30xx
  head/sys/arm/samsung/exynos/files.exynos5
  head/sys/arm/ti/files.ti
  head/sys/arm/versatile/files.versatile
  head/sys/arm/xilinx/files.zynq7
  head/sys/conf/files.arm

Modified: head/sys/arm/allwinner/files.allwinner
==
--- head/sys/arm/allwinner/files.allwinner  Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/allwinner/files.allwinner  Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,5 +1,4 @@
 # $FreeBSD$
-kern/kern_clocksource.cstandard
 
 arm/allwinner/a10_ahci.c   optionalahci
 arm/allwinner/a10_codec.c  optionalsound

Modified: head/sys/arm/altera/socfpga/files.socfpga
==
--- head/sys/arm/altera/socfpga/files.socfpga   Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/altera/socfpga/files.socfpga   Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,7 +1,5 @@
 # $FreeBSD$
 
-kern/kern_clocksource.cstandard
-
 arm/altera/socfpga/socfpga_common.cstandard
 arm/altera/socfpga/socfpga_machdep.c   standard
 arm/altera/socfpga/socfpga_manager.c   standard

Modified: head/sys/arm/amlogic/aml8726/files.aml8726
==
--- head/sys/arm/amlogic/aml8726/files.aml8726  Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/amlogic/aml8726/files.aml8726  Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,7 +1,5 @@
 #$FreeBSD$
 
-kern/kern_clocksource.cstandard
-
 arm/amlogic/aml8726/aml8726_l2cache.c  standard
 
 arm/amlogic/aml8726/aml8726_machdep.c  standard

Modified: head/sys/arm/annapurna/alpine/files.alpine
==
--- head/sys/arm/annapurna/alpine/files.alpine  Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/annapurna/alpine/files.alpine  Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,7 +1,5 @@
 # $FreeBSD$
 
-kern/kern_clocksource.cstandard
-
 arm/versatile/sp804.c  standard
 dev/uart/uart_dev_ns8250.c optionaluart
 

Modified: head/sys/arm/broadcom/bcm2835/files.bcm283x
==
--- head/sys/arm/broadcom/bcm2835/files.bcm283x Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/broadcom/bcm2835/files.bcm283x Wed Dec 27 21:39:57 2017
(r327250)
@@ -17,8 +17,6 @@ arm/broadcom/bcm2835/bcm2835_vcio.c   standard
 arm/broadcom/bcm2835/bcm2835_wdog.cstandard
 arm/broadcom/bcm2835/bcm283x_dwc_fdt.c optional dwcotg fdt
 
-kern/kern_clocksource.c standard
-
 dev/mbox/mbox_if.m standard
 
 arm/broadcom/bcm2835/bcm2835_audio.c   optional sound vchiq \

Modified: head/sys/arm/freescale/imx/files.imx5
==
--- head/sys/arm/freescale/imx/files.imx5   Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/freescale/imx/files.imx5   Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,5 +1,4 @@
 # $FreeBSD$
-kern/kern_clocksource.cstandard
 
 # Init
 arm/freescale/imx/imx_common.c standard

Modified: head/sys/arm/freescale/imx/files.imx6
==
--- head/sys/arm/freescale/imx/files.imx6   Wed Dec 27 21:36:37 2017
(r327249)
+++ head/sys/arm/freescale/imx/files.imx6   Wed Dec 27 21:39:57 2017
(r327250)
@@ -1,11 +1,6 @@
 # $FreeBSD$
 
 #
-# Standard ARM support.
-#
-kern/kern_clocksource.cstandard
-
-#
 # Standard imx6 devices and support.
 #
 arm/freescale/fsl_ocotp.c  standard

Modified: head/sys/arm/freescale/vybrid/files.vybrid
==
--- head/sys/arm/f

Re: svn commit: r327166 - head/sys/x86/isa

2017-12-27 Thread John Baldwin
On 12/24/17 9:59 AM, Warner Losh wrote:
> Author: imp
> Date: Sun Dec 24 17:59:48 2017
> New Revision: 327166
> URL: https://svnweb.freebsd.org/changeset/base/327166
> 
> Log:
>   Further investigation shows this shouldn't have been added at all.
>   Remove it.
> 
> Modified:
>   head/sys/x86/isa/orm.c
> 
> Modified: head/sys/x86/isa/orm.c
> ==
> --- head/sys/x86/isa/orm.cSun Dec 24 16:53:55 2017(r327165)
> +++ head/sys/x86/isa/orm.cSun Dec 24 17:59:48 2017(r327166)
> @@ -156,7 +156,6 @@ orm_identify(driver_t* driver, device_t parent)
>   device_set_desc(child, "ISA Option ROM");
>   else
>   device_set_desc(child, "ISA Option ROMs");
> -//   isa_set_vendorid(child, PNP_EISAID("PNP0C80"));
>  }

So does this mean orm0 will trigger warnings in GENERIC now?

-- 
John Baldwin
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327251 - in head/sys/arm: allwinner freescale/imx

2017-12-27 Thread Emmanuel Vadot
Author: manu
Date: Wed Dec 27 21:58:19 2017
New Revision: 327251
URL: https://svnweb.freebsd.org/changeset/base/327251

Log:
  arm: hdmi_if.m is already in files.arm
  
  Do not require it in files.vendor

Modified:
  head/sys/arm/allwinner/files.allwinner
  head/sys/arm/freescale/imx/files.imx6

Modified: head/sys/arm/allwinner/files.allwinner
==
--- head/sys/arm/allwinner/files.allwinner  Wed Dec 27 21:39:57 2017
(r327250)
+++ head/sys/arm/allwinner/files.allwinner  Wed Dec 27 21:58:19 2017
(r327251)
@@ -33,7 +33,6 @@ arm/allwinner/aw_cir.coptional
aw_cir evdev
 arm/allwinner/a10_fb.c optionalvt
 arm/allwinner/a10_hdmi.c   optionalhdmi
 arm/allwinner/a10_hdmiaudio.c  optionalhdmi sound
-dev/hdmi/hdmi_if.m optionalhdmi
 
 arm/allwinner/aw_reset.c   standard
 arm/allwinner/aw_ccu.c standard

Modified: head/sys/arm/freescale/imx/files.imx6
==
--- head/sys/arm/freescale/imx/files.imx6   Wed Dec 27 21:39:57 2017
(r327250)
+++ head/sys/arm/freescale/imx/files.imx6   Wed Dec 27 21:58:19 2017
(r327251)
@@ -22,7 +22,6 @@ arm/freescale/imx/imx6_audmux.c   optional sound
 arm/freescale/imx/imx6_ssi.c   optional sound
 arm/freescale/imx/imx6_ahci.c  optional ahci
 
-dev/hdmi/hdmi_if.m optional hdmi
 dev/hdmi/dwc_hdmi.coptional hdmi
 arm/freescale/imx/imx6_hdmi.c  optional hdmi
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327252 - head/sys/sparc64/include

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 22:01:30 2017
New Revision: 327252
URL: https://svnweb.freebsd.org/changeset/base/327252

Log:
  sparc64: Update idprom.h.
  
  We only take a small part of the NetBSD file in sys/dev/sun/idprom.h.
  Bring some comments and update the license.
  
  Obtained from:NetBSD (CVS rev 1.3)

Modified:
  head/sys/sparc64/include/idprom.h

Modified: head/sys/sparc64/include/idprom.h
==
--- head/sys/sparc64/include/idprom.h   Wed Dec 27 21:58:19 2017
(r327251)
+++ head/sys/sparc64/include/idprom.h   Wed Dec 27 22:01:30 2017
(r327252)
@@ -1,9 +1,12 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-2-Clause-NetBSD
  *
- * Copyright (c) 1993 Adam Glass
+ * Copyright (c) 1996 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
+ * This code is derived from software contributed to The NetBSD Foundation
+ * by Adam Glass.
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -12,25 +15,20 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *notice, this list of conditions and the following disclaimer in the
  *documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *must display the following acknowledgement:
- * This product includes software developed by Adam Glass.
- * 4. The name of the Author may not be used to endorse or promote products
- *derived from this software without specific prior written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY Adam Glass ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  *
- * from: NetBSD: idprom.h,v 1.2 1998/09/05 23:57:26 eeh Exp
+ * from: NetBSD: idprom.h,v 1.3 2008/04/28 20:23:58 martin Exp
  *
  * $FreeBSD$
  */
@@ -52,13 +50,14 @@ struct idprom {
int id_date;/* date of manufacture */
u_char  id_hostid[3];   /* ``host id'' bytes */
u_char  id_checksum;/* xor of everything else */
+   /* Note: The rest is excluded from the checksum! */
charid_undef[16];   /* undefined */
 };
 
-#define ID_SUN4_1000x22
-#define ID_SUN4_2000x21
-#define ID_SUN4_3000x23
-#define ID_SUN4_4000x24
+#defineID_SUN4_100 0x22/* Sun 4/100 */
+#defineID_SUN4_200 0x21/* Sun 4/200 */
+#defineID_SUN4_300 0x23/* Sun 4/300 */
+#defineID_SUN4_400 0x24/* Sun 4/400 */
 
 #define IDPROM_VERSION 1
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r327166 - head/sys/x86/isa

2017-12-27 Thread Warner Losh
On Dec 27, 2017 2:56 PM, "John Baldwin"  wrote:

On 12/24/17 9:59 AM, Warner Losh wrote:
> Author: imp
> Date: Sun Dec 24 17:59:48 2017
> New Revision: 327166
> URL: https://svnweb.freebsd.org/changeset/base/327166
>
> Log:
>   Further investigation shows this shouldn't have been added at all.
>   Remove it.
>
> Modified:
>   head/sys/x86/isa/orm.c
>
> Modified: head/sys/x86/isa/orm.c
> 
==
> --- head/sys/x86/isa/orm.cSun Dec 24 16:53:55 2017(r327165)
> +++ head/sys/x86/isa/orm.cSun Dec 24 17:59:48 2017(r327166)
> @@ -156,7 +156,6 @@ orm_identify(driver_t* driver, device_t parent)
>   device_set_desc(child, "ISA Option ROM");
>   else
>   device_set_desc(child, "ISA Option ROMs");
> -//   isa_set_vendorid(child, PNP_EISAID("PNP0C80"));
>  }

So does this mean orm0 will trigger warnings in GENERIC now?


No. The setting was redundant.

Warner
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327253 - head/sbin/dump

2017-12-27 Thread Kirk McKusick
Author: mckusick
Date: Wed Dec 27 22:18:56 2017
New Revision: 327253
URL: https://svnweb.freebsd.org/changeset/base/327253

Log:
  In preparation for converting to libufs to read the superblock,
  change conflicting function names:
  
getino => getinode
bread => blkread
  
  No functional change.

Modified:
  head/sbin/dump/dump.h
  head/sbin/dump/main.c
  head/sbin/dump/tape.c
  head/sbin/dump/traverse.c

Modified: head/sbin/dump/dump.h
==
--- head/sbin/dump/dump.h   Wed Dec 27 22:01:30 2017(r327252)
+++ head/sbin/dump/dump.h   Wed Dec 27 22:18:56 2017(r327253)
@@ -108,7 +108,7 @@ int mapfiles(ino_t maxino, long *tapesize);
 intmapdirs(ino_t maxino, long *tapesize);
 
 /* file dumping routines */
-void   bread(ufs2_daddr_t blkno, char *buf, int size);
+void   blkread(ufs2_daddr_t blkno, char *buf, int size);
 ssize_t cread(int fd, void *buf, size_t nbytes, off_t offset);
 void   dumpino(union dinode *dp, ino_t ino);
 void   dumpmap(char *map, int type, ino_t ino);
@@ -127,7 +127,7 @@ voiddumpabort(int signo) __dead2;
 void   dump_getfstab(void);
 
 char   *rawname(char *cp);
-union  dinode *getino(ino_t inum, int *mode);
+union  dinode *getinode(ino_t inum, int *mode);
 
 /* rdump routines */
 #ifdef RDUMP

Modified: head/sbin/dump/main.c
==
--- head/sbin/dump/tape.c   Wed Dec 27 22:01:30 2017(r327252)
+++ head/sbin/dump/tape.c   Wed Dec 27 22:18:56 2017(r327253)
@@ -786,7 +786,7 @@ doslave(int cmd, int slave_number)
for (trecno = 0; trecno < ntrec;
 trecno += p->count, p += p->count) {
if (p->dblk) {
-   bread(p->dblk, slp->tblock[trecno],
+   blkread(p->dblk, slp->tblock[trecno],
p->count * TP_BSIZE);
} else {
if (p->count != 1 || atomic(read, cmd,

Modified: head/sbin/dump/traverse.c
==
--- head/sbin/dump/traverse.c   Wed Dec 27 22:01:30 2017(r327252)
+++ head/sbin/dump/traverse.c   Wed Dec 27 22:18:56 2017(r327253)
@@ -162,7 +162,7 @@ mapfiles(ino_t maxino, long *tapesize)
quit("mapfiles: cannot allocate memory.\n");
for (cg = 0; cg < sblock->fs_ncg; cg++) {
ino = cg * sblock->fs_ipg;
-   bread(fsbtodb(sblock, cgtod(sblock, cg)), (char *)cgp,
+   blkread(fsbtodb(sblock, cgtod(sblock, cg)), (char *)cgp,
sblock->fs_cgsize);
if (sblock->fs_magic == FS_UFS2_MAGIC)
inosused = cgp->cg_initediblk;
@@ -194,7 +194,7 @@ mapfiles(ino_t maxino, long *tapesize)
}
for (i = 0; i < inosused; i++, ino++) {
if (ino < UFS_ROOTINO ||
-   (dp = getino(ino, &mode)) == NULL ||
+   (dp = getinode(ino, &mode)) == NULL ||
(mode & IFMT) == 0)
continue;
if (ino >= maxino) {
@@ -276,7 +276,7 @@ mapdirs(ino_t maxino, long *tapesize

svn commit: r327254 - head/sys/dev/cxgbe/iw_cxgbe

2017-12-27 Thread Navdeep Parhar
Author: np
Date: Wed Dec 27 22:44:50 2017
New Revision: 327254
URL: https://svnweb.freebsd.org/changeset/base/327254

Log:
  cxgbe/iw_cxgbe: Fix iWARP over VLANs (catch up with r326169).
  
  Submitted by: KrishnamRaju ErapaRaju @ Chelsio
  Sponsored by: Chelsio Communications

Modified:
  head/sys/dev/cxgbe/iw_cxgbe/cm.c

Modified: head/sys/dev/cxgbe/iw_cxgbe/cm.c
==
--- head/sys/dev/cxgbe/iw_cxgbe/cm.cWed Dec 27 22:18:56 2017
(r327253)
+++ head/sys/dev/cxgbe/iw_cxgbe/cm.cWed Dec 27 22:44:50 2017
(r327254)
@@ -339,24 +339,28 @@ find_real_listen_ep(struct c4iw_listen_ep *master_lep,
 {
struct adapter *adap = NULL;
struct c4iw_listen_ep *lep = NULL;
-   struct sockaddr_storage remote = { 0 };
-   struct ifnet *new_conn_ifp = NULL;
+   struct ifnet *ifp = NULL, *hw_ifp = NULL;
struct listen_port_info *port_info = NULL;
-   int err = 0, i = 0,
-   found_portinfo = 0, found_lep = 0;
+   int i = 0, found_portinfo = 0, found_lep = 0;
uint16_t port;
 
-   /* STEP 1: get 'ifnet' based on socket's remote address */
-   GET_REMOTE_ADDR(&remote, so);
+   /*
+* STEP 1: Figure out 'ifp' of the physical interface, not pseudo
+* interfaces like vlan, lagg, etc..
+* TBD: lagg support, lagg + vlan support.
+*/
+   ifp = TOEPCB(so)->l2te->ifp;
+   if (ifp->if_type == IFT_L2VLAN) {
+   hw_ifp = VLAN_TRUNKDEV(ifp);
+   if (hw_ifp == NULL) {
+   CTR4(KTR_IW_CXGBE, "%s: Failed to get parent ifnet of "
+   "vlan ifnet %p, sock %p, master_lep %p",
+   __func__, ifp, so, master_lep);
+   return (NULL);
+   }
+   } else
+   hw_ifp = ifp;
 
-   err = get_ifnet_from_raddr(&remote, &new_conn_ifp);
-   if (err) {
-   CTR4(KTR_IW_CXGBE, "%s: Failed to get ifnet, sock %p, "
-   "master_lep %p err %d",
-   __func__, so, master_lep, err);
-   return (NULL);
-   }
-
/* STEP 2: Find 'port_info' with listener local port address. */
port = (master_lep->com.local_addr.ss_family == AF_INET) ?
((struct sockaddr_in *)&master_lep->com.local_addr)->sin_port :
@@ -379,7 +383,7 @@ find_real_listen_ep(struct c4iw_listen_ep *master_lep,
list_for_each_entry(lep, &port_info->lep_list, listen_ep_list) {
adap = lep->com.dev->rdev.adap;
for_each_port(adap, i) {
-   if (new_conn_ifp == adap->port[i]->vi[0].ifp) {
+   if (hw_ifp == adap->port[i]->vi[0].ifp) {
found_lep =1;
goto out;
}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327255 - head/sys/arm/xscale/ixp425

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Dec 27 22:47:56 2017
New Revision: 327255
URL: https://svnweb.freebsd.org/changeset/base/327255

Log:
  SPDX: fix license ID tags for arm/xscale.
  
  Use parenthesis for grouping as suggested by the spec.

Modified:
  head/sys/arm/xscale/ixp425/ixp425_npe.c
  head/sys/arm/xscale/ixp425/ixp425_npereg.h

Modified: head/sys/arm/xscale/ixp425/ixp425_npe.c
==
--- head/sys/arm/xscale/ixp425/ixp425_npe.c Wed Dec 27 22:44:50 2017
(r327254)
+++ head/sys/arm/xscale/ixp425/ixp425_npe.c Wed Dec 27 22:47:56 2017
(r327255)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2006-2008 Sam Leffler, Errno Consulting
  * All rights reserved.

Modified: head/sys/arm/xscale/ixp425/ixp425_npereg.h
==
--- head/sys/arm/xscale/ixp425/ixp425_npereg.h  Wed Dec 27 22:44:50 2017
(r327254)
+++ head/sys/arm/xscale/ixp425/ixp425_npereg.h  Wed Dec 27 22:47:56 2017
(r327255)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-License-Identifier: (BSD-2-Clause-FreeBSD AND BSD-3-Clause)
  *
  * Copyright (c) 2006 Sam Leffler, Errno Consulting
  * All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327256 - head/sys/arm/xscale/ixp425

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Thu Dec 28 01:12:28 2017
New Revision: 327256
URL: https://svnweb.freebsd.org/changeset/base/327256

Log:
  arm/ixp425: Drop 3rd and 4th clauses from Ichiro FUKUHARA's license.
  
  This syncs us with NetBSD as much of our changes have been upstreamed.
  
  Obtained from:NetBSD

Modified:
  head/sys/arm/xscale/ixp425/ixdp425_pci.c
  head/sys/arm/xscale/ixp425/ixdp425reg.h
  head/sys/arm/xscale/ixp425/ixp425.c
  head/sys/arm/xscale/ixp425/ixp425_pci.c
  head/sys/arm/xscale/ixp425/ixp425_pci_space.c
  head/sys/arm/xscale/ixp425/ixp425_space.c
  head/sys/arm/xscale/ixp425/ixp425_timer.c
  head/sys/arm/xscale/ixp425/ixp425reg.h
  head/sys/arm/xscale/ixp425/ixp425var.h

Modified: head/sys/arm/xscale/ixp425/ixdp425_pci.c
==
--- head/sys/arm/xscale/ixp425/ixdp425_pci.cWed Dec 27 22:47:56 2017
(r327255)
+++ head/sys/arm/xscale/ixp425/ixdp425_pci.cThu Dec 28 01:12:28 2017
(r327256)
@@ -1,6 +1,6 @@
-/*  $NetBSD: ixdp425_pci.c,v 1.5 2005/12/11 12:17:09 christos Exp $ */
+/*  $NetBSD: ixdp425_pci.c,v 1.6 2009/10/21 14:15:51 rmind Exp $ */
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-2-Clause-NetBSD
  *
  * Copyright (c) 2003
  * Ichiro FUKUHARA .
@@ -14,12 +14,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *notice, this list of conditions and the following disclaimer in the
  *documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *must display the following acknowledgement:
- * This product includes software developed by Ichiro FUKUHARA.
- * 4. The name of the company nor the name of the author may be used to
- *endorse or promote products derived from this software without specific
- *prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY ICHIRO FUKUHARA ``AS IS'' AND ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES

Modified: head/sys/arm/xscale/ixp425/ixdp425reg.h
==
--- head/sys/arm/xscale/ixp425/ixdp425reg.h Wed Dec 27 22:47:56 2017
(r327255)
+++ head/sys/arm/xscale/ixp425/ixdp425reg.h Thu Dec 28 01:12:28 2017
(r327256)
@@ -1,6 +1,6 @@
-/* $NetBSD: ixdp425reg.h,v 1.6 2005/12/11 12:17:09 christos Exp $ */
+/* $NetBSD: ixdp425reg.h,v 1.7 2009/10/21 14:15:51 rmind Exp $ */
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-2-Clause-NetBSD
  *
  * Copyright (c) 2003
  * Ichiro FUKUHARA .
@@ -14,12 +14,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *notice, this list of conditions and the following disclaimer in the
  *documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *must display the following acknowledgement:
- * This product includes software developed by Ichiro FUKUHARA.
- * 4. The name of the company nor the name of the author may be used to
- *endorse or promote products derived from this software without specific
- *prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY ICHIRO FUKUHARA ``AS IS'' AND ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES

Modified: head/sys/arm/xscale/ixp425/ixp425.c
==
--- head/sys/arm/xscale/ixp425/ixp425.c Wed Dec 27 22:47:56 2017
(r327255)
+++ head/sys/arm/xscale/ixp425/ixp425.c Thu Dec 28 01:12:28 2017
(r327256)
@@ -1,7 +1,7 @@
-/* $NetBSD: ixp425.c,v 1.10 2005/12/11 12:16:51 christos Exp $ */
+/* $NetBSD: ixp425.c,v 1.13 2009/10/21 14:15:50 rmind Exp $ */
 
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-2-Clause-NetBSD
  *
  * Copyright (c) 2003
  * Ichiro FUKUHARA .
@@ -15,12 +15,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *notice, this list of conditions and the following disclaimer in the
  *documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *must display the following acknowledgement:
- * This product includes software developed by Ichiro FUKUHARA.
- * 4. The name of the company nor the name of the author may be used to
- *endorse or promote products derived from this software without specific
- *prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY ICHIRO FUKUHARA ``AS IS'' AND ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES

Modified: head/sys/arm/xscale/ixp425/ixp425_pci.c
===

svn commit: r327257 - head/sys/libkern

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Thu Dec 28 01:20:30 2017
New Revision: 327257
URL: https://svnweb.freebsd.org/changeset/base/327257

Log:
  SPDX: fix wrong license ID tag in libkern.

Modified:
  head/sys/libkern/strstr.c

Modified: head/sys/libkern/strstr.c
==
--- head/sys/libkern/strstr.c   Thu Dec 28 01:12:28 2017(r327256)
+++ head/sys/libkern/strstr.c   Thu Dec 28 01:20:30 2017(r327257)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Copyright (c) 1990, 1993
  * The Regents of the University of California.  All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327259 - in head: lib/libc/sys lib/libopenbsd sbin/ipfw usr.sbin/ntp/doc

2017-12-27 Thread Eitan Adler
Author: eadler
Date: Thu Dec 28 01:31:28 2017
New Revision: 327259
URL: https://svnweb.freebsd.org/changeset/base/327259

Log:
  Fix a few more speelling errors
  
  Reviewed by:  bjk
  Reviewed by:  jilles (incl formal "accept")
  Differential Revision:https://reviews.freebsd.org/D13650

Modified:
  head/lib/libc/sys/kqueue.2
  head/lib/libc/sys/sendfile.2
  head/lib/libopenbsd/imsg_init.3
  head/sbin/ipfw/ipfw.8
  head/usr.sbin/ntp/doc/ntp.conf.5

Modified: head/lib/libc/sys/kqueue.2
==
--- head/lib/libc/sys/kqueue.2  Thu Dec 28 01:21:30 2017(r327258)
+++ head/lib/libc/sys/kqueue.2  Thu Dec 28 01:31:28 2017(r327259)
@@ -190,7 +190,7 @@ The
 .Fa ext[2]
 and
 .Fa ext[3]
-members are always passed throught the kernel as-is,
+members are always passed through the kernel as-is,
 making additional context available to application.
 .El
 .Pp

Modified: head/lib/libc/sys/sendfile.2
==
--- head/lib/libc/sys/sendfile.2Thu Dec 28 01:21:30 2017
(r327258)
+++ head/lib/libc/sys/sendfile.2Thu Dec 28 01:31:28 2017
(r327259)
@@ -190,7 +190,7 @@ may read ahead when reading the file.
 A macro
 .Fn SF_FLAGS
 is provided to combine readahead amount and flags.
-Example shows specifing readahead of 16 pages and
+An example showing specifying readahead of 16 pages and
 .Dv SF_NOCACHE
 flag:
 .Pp

Modified: head/lib/libopenbsd/imsg_init.3
==
--- head/lib/libopenbsd/imsg_init.3 Thu Dec 28 01:21:30 2017
(r327258)
+++ head/lib/libopenbsd/imsg_init.3 Thu Dec 28 01:31:28 2017
(r327259)
@@ -347,7 +347,7 @@ On success
 returns a pointer to the buffer; on failure it returns NULL.
 .Pp
 .Fn ibuf_dynamic
-allocates a resizeable buffer of initial length
+allocates a resizable buffer of initial length
 .Fa len
 and maximum size
 .Fa max .

Modified: head/sbin/ipfw/ipfw.8
==
--- head/sbin/ipfw/ipfw.8   Thu Dec 28 01:21:30 2017(r327258)
+++ head/sbin/ipfw/ipfw.8   Thu Dec 28 01:31:28 2017(r327259)
@@ -3020,7 +3020,7 @@ supports in-kernel IPv6/IPv4 network address and proto
 Stateful NAT64 translation allows IPv6-only clients to contact IPv4 servers
 using unicast TCP, UDP or ICMP protocols.
 One or more IPv4 addresses assigned to a stateful NAT64 translator are shared
-among serveral IPv6-only clients.
+among several IPv6-only clients.
 When stateful NAT64 is used in conjunction with DNS64, no changes are usually
 required in the IPv6 client or the IPv4 server.
 The kernel module

Modified: head/usr.sbin/ntp/doc/ntp.conf.5
==
--- head/usr.sbin/ntp/doc/ntp.conf.5Thu Dec 28 01:21:30 2017
(r327258)
+++ head/usr.sbin/ntp/doc/ntp.conf.5Thu Dec 28 01:31:28 2017
(r327259)
@@ -2550,7 +2550,7 @@ While this is generally a feature
 as it allows for quick recovery if a server key has changed,
 a properly forged and appropriately delivered crypto\-NAK packet
 can be used in a DoS attack.
-If you have active noticable problems with this type of DoS attack
+If you have active noticeable problems with this type of DoS attack
 then you should consider
 disabling this option.
 You can check your
@@ -2598,7 +2598,7 @@ While this is generally a feature
 as it allows for quick recovery if a server key has changed,
 a properly forged and appropriately delivered crypto\-NAK packet
 can be used in a DoS attack.
-If you have active noticable problems with this type of DoS attack
+If you have active noticeable problems with this type of DoS attack
 then you should consider
 disabling this option.
 You can check your
@@ -2618,7 +2618,7 @@ While this is generally a feature
 as it allows for quick recovery,
 if this type of packet is carefully forged and sent
 during an appropriate window it can be used for a DoS attack.
-If you have active noticable problems with this type of DoS attack
+If you have active noticeable problems with this type of DoS attack
 then you should consider
 disabling this option.
 You can check your
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327258 - head/usr.sbin/bsdinstall/partedit

2017-12-27 Thread Nathan Whitehorn
Author: nwhitehorn
Date: Thu Dec 28 01:21:30 2017
New Revision: 327258
URL: https://svnweb.freebsd.org/changeset/base/327258

Log:
  Fix bug introduced in r326674, in which efi boot partitions created by
  the installer but not mounted (i.e. with boot1.efifat dd'ed to them
  rather than the forthcoming proper filesystem) would get newfs_msdos run
  on them immediately after the boot code was copied. This would overwrite
  the bootstrap code, causing the EFI system partition to be blanked and
  resulting in an unbootable system.
  
  PR:   224562

Modified:
  head/usr.sbin/bsdinstall/partedit/gpart_ops.c

Modified: head/usr.sbin/bsdinstall/partedit/gpart_ops.c
==
--- head/usr.sbin/bsdinstall/partedit/gpart_ops.c   Thu Dec 28 01:20:30 
2017(r327257)
+++ head/usr.sbin/bsdinstall/partedit/gpart_ops.c   Thu Dec 28 01:21:30 
2017(r327258)
@@ -942,7 +942,9 @@ add_boot_partition(struct ggeom *geom, struct gprovide
choice = 0;
 
if (choice == 0) { /* yes */
+   struct partition_metadata *md;
const char *bootmount = NULL;
+   char *bootpartname = NULL;
char sizestr[7];
 
humanize_number(sizestr, 7,
@@ -950,7 +952,21 @@ add_boot_partition(struct ggeom *geom, struct gprovide
HN_NOSPACE | HN_DECIMAL);
 
gpart_create(pp, bootpart_type(scheme, &bootmount),
-   sizestr, bootmount, NULL, 0);
+   sizestr, bootmount, &bootpartname, 0);
+
+   if (bootpartname == NULL) /* Error reported to user already */
+   return 0;
+
+   /* If the part is not mountable, make sure newfs isn't set */
+   if (bootmount == NULL) {
+   md = get_part_metadata(bootpartname, 0);
+   if (md != NULL && md->newfs != NULL) {
+   free(md->newfs);
+   md->newfs = NULL;
+   }
+   }
+
+   free(bootpartname);
 
return (bootpart_size(scheme));
}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327260 - head/sys/dev/spibus

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Thu Dec 28 03:04:36 2017
New Revision: 327260
URL: https://svnweb.freebsd.org/changeset/base/327260

Log:
  SPDX: fix wrong license ID tag in dev/spibus.

Modified:
  head/sys/dev/spibus/ofw_spibus.c

Modified: head/sys/dev/spibus/ofw_spibus.c
==
--- head/sys/dev/spibus/ofw_spibus.cThu Dec 28 01:31:28 2017
(r327259)
+++ head/sys/dev/spibus/ofw_spibus.cThu Dec 28 03:04:36 2017
(r327260)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause-FreeBSD
+ * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
  *
  * Copyright (c) 2009, Nathan Whitehorn 
  * Copyright (c) 2013 The FreeBSD Foundation
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327261 - head/sys/dev/cesa

2017-12-27 Thread Pedro F. Giffuni
Author: pfg
Date: Thu Dec 28 03:10:57 2017
New Revision: 327261
URL: https://svnweb.freebsd.org/changeset/base/327261

Log:
  SPDX: fix wrong license ID tag in dev/cesa.

Modified:
  head/sys/dev/cesa/cesa.h

Modified: head/sys/dev/cesa/cesa.h
==
--- head/sys/dev/cesa/cesa.hThu Dec 28 03:04:36 2017(r327260)
+++ head/sys/dev/cesa/cesa.hThu Dec 28 03:10:57 2017(r327261)
@@ -1,5 +1,5 @@
 /*-
- * SPDX-License-Identifier: BSD-4-Clause-FreeBSD
+ * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
  *
  * Copyright (C) 2009-2011 Semihalf.
  * All rights reserved.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327263 - head/usr.sbin/btxld

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:19 2017
New Revision: 327263
URL: https://svnweb.freebsd.org/changeset/base/327263

Log:
  Explicitly ignore return value from remove. We wouldn't do anything
  differently if we can't unlink the temporary file. Also, free the
  temporary file name when we set it to NULL.
  
  CID: 1006909, 719448

Modified:
  head/usr.sbin/btxld/btxld.c

Modified: head/usr.sbin/btxld/btxld.c
==
--- head/usr.sbin/btxld/btxld.c Thu Dec 28 05:32:59 2017(r327262)
+++ head/usr.sbin/btxld/btxld.c Thu Dec 28 05:33:19 2017(r327263)
@@ -189,7 +189,7 @@ static void
 cleanup(void)
 {
 if (tname)
-   remove(tname);
+   (void)remove(tname);
 }
 
 /*
@@ -287,6 +287,7 @@ btxld(const char *iname)
err(2, "%s", tname);
 if (rename(tname, oname))
err(2, "%s: Can't rename to %s", tname, oname);
+free((void*)(intptr_t)tname);
 tname = NULL;
 if (verbose) {
printf(binfo, btx.btx_majver, btx.btx_minver, btx.btx_textsz,
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327265 - head/usr.bin/rpcgen

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:29 2017
New Revision: 327265
URL: https://svnweb.freebsd.org/changeset/base/327265

Log:
  Plug two resource leaks.
  
  CID: 92077, 92074

Modified:
  head/usr.bin/rpcgen/rpc_parse.c
  head/usr.bin/rpcgen/rpc_scan.c

Modified: head/usr.bin/rpcgen/rpc_parse.c
==
--- head/usr.bin/rpcgen/rpc_parse.c Thu Dec 28 05:33:24 2017
(r327264)
+++ head/usr.bin/rpcgen/rpc_parse.c Thu Dec 28 05:33:29 2017
(r327265)
@@ -93,6 +93,7 @@ get_definition(void)
def_const(defp);
break;
case TOK_EOF:
+   free(defp);
return (NULL);
default:
error("definition keyword expected");

Modified: head/usr.bin/rpcgen/rpc_scan.c
==
--- head/usr.bin/rpcgen/rpc_scan.c  Thu Dec 28 05:33:24 2017
(r327264)
+++ head/usr.bin/rpcgen/rpc_scan.c  Thu Dec 28 05:33:29 2017
(r327265)
@@ -490,6 +490,7 @@ docppline(char *line, int *lineno, const char **fname)
*p = 0;
if (*file == 0) {
*fname = NULL;
+   free(file);
} else {
*fname = file;
}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327262 - head/usr.sbin/binmiscctl

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:32:59 2017
New Revision: 327262
URL: https://svnweb.freebsd.org/changeset/base/327262

Log:
  Don't leak resources on duplicate -m or -M arguments. Last one wins.
  
  CID: 1204385, 1204384

Modified:
  head/usr.sbin/binmiscctl/binmiscctl.c

Modified: head/usr.sbin/binmiscctl/binmiscctl.c
==
--- head/usr.sbin/binmiscctl/binmiscctl.c   Thu Dec 28 03:10:57 2017
(r327261)
+++ head/usr.sbin/binmiscctl/binmiscctl.c   Thu Dec 28 05:32:59 2017
(r327262)
@@ -299,10 +299,12 @@ add_cmd(__unused int argc, char *argv[], ximgact_binmi
break;
 
case 'm':
+   free(magic);
magic = strdup(optarg);
break;
 
case 'M':
+   free(mask);
mask = strdup(optarg);
xbe->xbe_flags |= IBF_USE_MASK;
break;
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327264 - head/usr.sbin/cpucontrol

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:24 2017
New Revision: 327264
URL: https://svnweb.freebsd.org/changeset/base/327264

Log:
  Use proper failure path rather than just returning.
  
  CID: 1199354, 1006894, 1006893, 1006892

Modified:
  head/usr.sbin/cpucontrol/intel.c
  head/usr.sbin/cpucontrol/via.c

Modified: head/usr.sbin/cpucontrol/intel.c
==
--- head/usr.sbin/cpucontrol/intel.cThu Dec 28 05:33:19 2017
(r327263)
+++ head/usr.sbin/cpucontrol/intel.cThu Dec 28 05:33:24 2017
(r327264)
@@ -261,7 +261,7 @@ matched:
if (revision >= fw_header->revision) {
WARNX(1, "skipping %s of rev %#x: up to date",
path, fw_header->revision);
-   return;
+   goto fail;
}
fprintf(stderr, "%s: updating cpu %s from rev %#x to rev %#x... ",
path, dev, revision, fw_header->revision);

Modified: head/usr.sbin/cpucontrol/via.c
==
--- head/usr.sbin/cpucontrol/via.c  Thu Dec 28 05:33:19 2017
(r327263)
+++ head/usr.sbin/cpucontrol/via.c  Thu Dec 28 05:33:24 2017
(r327264)
@@ -140,7 +140,7 @@ via_update(const char *dev, const char *path)
fd = open(path, O_RDONLY, 0);
if (fd < 0) {
WARN(0, "open(%s)", path);
-   return;
+   goto fail;
}
error = fstat(fd, &st);
if (error != 0) {
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327267 - head/usr.bin/tcopy

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:39 2017
New Revision: 327267
URL: https://svnweb.freebsd.org/changeset/base/327267

Log:
  Free inb on error return.
  
  CID: 270099

Modified:
  head/usr.bin/tcopy/tcopy.c

Modified: head/usr.bin/tcopy/tcopy.c
==
--- head/usr.bin/tcopy/tcopy.c  Thu Dec 28 05:33:34 2017(r327266)
+++ head/usr.bin/tcopy/tcopy.c  Thu Dec 28 05:33:39 2017(r327267)
@@ -263,6 +263,7 @@ r2: if (inn != outn) {
if (!inn) {
if (eot++) {
fprintf(msg, "tcopy: tapes are identical.\n");
+   free(inb);
return;
}
} else {
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327268 - head/usr.bin/column

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:44 2017
New Revision: 327268
URL: https://svnweb.freebsd.org/changeset/base/327268

Log:
  Free data after we're done with it.
  
  CID: 271595, 275337, 1368743

Modified:
  head/usr.bin/column/column.c

Modified: head/usr.bin/column/column.c
==
--- head/usr.bin/column/column.cThu Dec 28 05:33:39 2017
(r327267)
+++ head/usr.bin/column/column.cThu Dec 28 05:33:44 2017
(r327268)
@@ -270,7 +270,12 @@ maketbl(void)
(void)wprintf(L"%ls%*ls", t->list[coloff],
lens[coloff] - t->len[coloff] + 2, L" ");
(void)wprintf(L"%ls\n", t->list[coloff]);
+   free(t->list);
+   free(t->len);
}
+   free(lens);
+   free(cols);
+   free(tbl);
 }
 
 #defineDEFNUM  1000
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327266 - head/usr.bin/rpcgen

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:34 2017
New Revision: 327266
URL: https://svnweb.freebsd.org/changeset/base/327266

Log:
  Free some variables before they go out of scope.
  
  CID: 92074, 270099

Modified:
  head/usr.bin/rpcgen/rpc_main.c

Modified: head/usr.bin/rpcgen/rpc_main.c
==
--- head/usr.bin/rpcgen/rpc_main.c  Thu Dec 28 05:33:29 2017
(r327265)
+++ head/usr.bin/rpcgen/rpc_main.c  Thu Dec 28 05:33:34 2017
(r327266)
@@ -484,7 +484,9 @@ generate_guard(const char *pathname)
;
strcpy(guard, tmp);
}
+   tmp = guard;
guard = extendfile(guard, "_H_RPCGEN");
+   free(tmp);
return (guard);
 }
 
@@ -502,13 +504,14 @@ h_output(const char *infile, const char *define, int e
const char *guard;
list *l;
xdrfunc *xdrfuncp;
+   void *tmp = NULL;
 
open_input(infile, define);
outfilename =  extend ? extendfile(infile, outfile) : outfile;
open_output(infile, outfilename);
add_warning();
if (outfilename || infile){
-   guard = generate_guard(outfilename ? outfilename: infile);
+   guard = tmp = generate_guard(outfilename ? outfilename: infile);
} else
guard = "STDIN_";
 
@@ -574,6 +577,7 @@ h_output(const char *infile, const char *define, int e
f_print(fout, "#endif\n");
 
f_print(fout, "\n#endif /* !_%s */\n", guard);
+   free(tmp);
 }
 
 /*
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327270 - head/sbin/pfctl

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:54 2017
New Revision: 327270
URL: https://svnweb.freebsd.org/changeset/base/327270

Log:
  Free path before returnig.
  
  CID: 977827

Modified:
  head/sbin/pfctl/pfctl.c

Modified: head/sbin/pfctl/pfctl.c
==
--- head/sbin/pfctl/pfctl.c Thu Dec 28 05:33:49 2017(r327269)
+++ head/sbin/pfctl/pfctl.c Thu Dec 28 05:33:54 2017(r327270)
@@ -1510,6 +1510,7 @@ pfctl_rules(int dev, char *filename, int opts, int opt
if (pfctl_trans(dev, t, DIOCXCOMMIT, osize))
ERR("DIOCXCOMMIT");
}
+   free(path);
return (0);
 
 _error:
@@ -1519,6 +1520,7 @@ _error:
err(1, "DIOCXROLLBACK");
exit(1);
} else {/* sub ruleset */
+   free(path);
return (-1);
}
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327273 - head/sbin/fsdb

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:08 2017
New Revision: 327273
URL: https://svnweb.freebsd.org/changeset/base/327273

Log:
  Plug memory leak by freeing wantedblk{32,64}.
  
  CID: 273655, 273656

Modified:
  head/sbin/fsdb/fsdb.c

Modified: head/sbin/fsdb/fsdb.c
==
--- head/sbin/fsdb/fsdb.c   Thu Dec 28 05:34:04 2017(r327272)
+++ head/sbin/fsdb/fsdb.c   Thu Dec 28 05:34:08 2017(r327273)
@@ -565,6 +565,8 @@ CMDFUNCSTART(findblk)
 end:
 curinum = ocurrent;
 curinode = ginode(curinum);
+free(wantedblk32);
+free(wantedblk64);
 return 0;
 }
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327269 - head/usr.bin/msgs

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:49 2017
New Revision: 327269
URL: https://svnweb.freebsd.org/changeset/base/327269

Log:
  Close cpfrom in an error case.
  
  CID: 271771

Modified:
  head/usr.bin/msgs/msgs.c

Modified: head/usr.bin/msgs/msgs.c
==
--- head/usr.bin/msgs/msgs.cThu Dec 28 05:33:44 2017(r327268)
+++ head/usr.bin/msgs/msgs.cThu Dec 28 05:33:49 2017(r327269)
@@ -804,6 +804,7 @@ ask(const char *prompt)
mailing = NO;
fseeko(newmsg, oldpos, SEEK_SET);
ask(prompt);
+   fclose(cpfrom);
return;
}
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327278 - head/usr.bin/showmount

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:34 2017
New Revision: 327278
URL: https://svnweb.freebsd.org/changeset/base/327278

Log:
  Free mp on a couple of error paths.
  
  CID: 978387

Modified:
  head/usr.bin/showmount/showmount.c

Modified: head/usr.bin/showmount/showmount.c
==
--- head/usr.bin/showmount/showmount.c  Thu Dec 28 05:34:29 2017
(r327277)
+++ head/usr.bin/showmount/showmount.c  Thu Dec 28 05:34:34 2017
(r327278)
@@ -279,11 +279,15 @@ xdr_mntdump(XDR *xdrsp, struct mountlist **mlp)
return (0);
mp->ml_left = mp->ml_right = (struct mountlist *)0;
strp = mp->ml_host;
-   if (!xdr_string(xdrsp, &strp, MNTNAMLEN))
+   if (!xdr_string(xdrsp, &strp, MNTNAMLEN)) {
+   free(mp);
return (0);
+   }
strp = mp->ml_dirp;
-   if (!xdr_string(xdrsp, &strp, MNTPATHLEN))
+   if (!xdr_string(xdrsp, &strp, MNTPATHLEN)) {
+   free(mp);
return (0);
+   }
 
/*
 * Build a binary tree on sorted order of either host or dirp.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327276 - head/sbin/routed

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:24 2017
New Revision: 327276
URL: https://svnweb.freebsd.org/changeset/base/327276

Log:
  When bind fails, make sure we closed the socket we tried to bind the
  address to.
  
  CID: 978244

Modified:
  head/sbin/routed/main.c

Modified: head/sbin/routed/main.c
==
--- head/sbin/routed/main.c Thu Dec 28 05:34:19 2017(r327275)
+++ head/sbin/routed/main.c Thu Dec 28 05:34:24 2017(r327276)
@@ -667,6 +667,7 @@ get_rip_sock(naddr addr,
if (bind(s, (struct sockaddr *)&rsin, sizeof(rsin)) < 0) {
if (serious)
BADERR(errno != EADDRINUSE, "bind(rip_sock)");
+   close(s);
return -1;
}
fix_sock(s,"rip_sock");
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327275 - head/sbin/newfs_msdos

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:19 2017
New Revision: 327275
URL: https://svnweb.freebsd.org/changeset/base/327275

Log:
  Close fd and fd1 before returning now that we're done with them.
  
  CID: 978234, 978236

Modified:
  head/sbin/newfs_msdos/mkfs_msdos.c

Modified: head/sbin/newfs_msdos/mkfs_msdos.c
==
--- head/sbin/newfs_msdos/mkfs_msdos.c  Thu Dec 28 05:34:14 2017
(r327274)
+++ head/sbin/newfs_msdos/mkfs_msdos.c  Thu Dec 28 05:34:19 2017
(r327275)
@@ -247,6 +247,7 @@ mkfs_msdos(const char *fname, const char *dtype, const
 
 img = NULL;
 rv = -1;
+fd = fd1 = -1;
 
 if (o.block_size && o.sectors_per_cluster) {
warnx("Cannot specify both block size and sectors per cluster");
@@ -716,6 +717,8 @@ mkfs_msdos(const char *fname, const char *dtype, const
 rv = 0;
 done:
 free(img);
+close(fd);
+close(fd1);
 
 return rv;
 }
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327272 - head/usr.sbin/kgmon

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:04 2017
New Revision: 327272
URL: https://svnweb.freebsd.org/changeset/base/327272

Log:
  Free zbuf when kflag is true too.
  
  CID: 273376

Modified:
  head/usr.sbin/kgmon/kgmon.c

Modified: head/usr.sbin/kgmon/kgmon.c
==
--- head/usr.sbin/kgmon/kgmon.c Thu Dec 28 05:33:59 2017(r327271)
+++ head/usr.sbin/kgmon/kgmon.c Thu Dec 28 05:34:04 2017(r327272)
@@ -511,6 +511,7 @@ reset(struct kvmvars *kvp)
if (kvm_write(kvp->kd, (u_long)kvp->gpm.tos, zbuf,
kvp->gpm.tossize) != (ssize_t)kvp->gpm.tossize)
errx(15, "tos zero: %s", kvm_geterr(kvp->kd));
+   free(zbuf);
return;
}
(void)seteuid(0);
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327277 - head/usr.bin/wall

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:29 2017
New Revision: 327277
URL: https://svnweb.freebsd.org/changeset/base/327277

Log:
  Close the fp rather than the fd since we fdopen the fd so we don't
  leak the FILE *.
  
  CID: 978383

Modified:
  head/usr.bin/wall/wall.c

Modified: head/usr.bin/wall/wall.c
==
--- head/usr.bin/wall/wall.cThu Dec 28 05:34:24 2017(r327276)
+++ head/usr.bin/wall/wall.cThu Dec 28 05:34:29 2017(r327277)
@@ -290,5 +290,5 @@ makemsg(char *fname)
err(1, "out of memory");
if ((int)fread(mbuf, sizeof(*mbuf), mbufsize, fp) != mbufsize)
err(1, "can't read temporary file");
-   (void)close(fd);
+   fclose(fp);
 }
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327271 - head/lib/libutil

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:33:59 2017
New Revision: 327271
URL: https://svnweb.freebsd.org/changeset/base/327271

Log:
  Close slave on fork error to prevent pty fd leak.
  
  CID: 978209

Modified:
  head/lib/libutil/pty.c

Modified: head/lib/libutil/pty.c
==
--- head/lib/libutil/pty.c  Thu Dec 28 05:33:54 2017(r327270)
+++ head/lib/libutil/pty.c  Thu Dec 28 05:33:59 2017(r327271)
@@ -101,12 +101,13 @@ forkpty(int *amaster, char *name, struct termios *term
return (-1);
switch (pid = fork()) {
case -1:
+   (void)close(slave);
return (-1);
case 0:
/*
 * child
 */
-   (void) close(master);
+   (void)close(master);
login_tty(slave);
return (0);
}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327274 - head/usr.sbin/ndiscvt

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:14 2017
New Revision: 327274
URL: https://svnweb.freebsd.org/changeset/base/327274

Log:
  Don't leak outfile. Free it before we return from bincvt.
  
  CID: 273685

Modified:
  head/usr.sbin/ndiscvt/ndiscvt.c

Modified: head/usr.sbin/ndiscvt/ndiscvt.c
==
--- head/usr.sbin/ndiscvt/ndiscvt.c Thu Dec 28 05:34:08 2017
(r327273)
+++ head/usr.sbin/ndiscvt/ndiscvt.c Thu Dec 28 05:34:14 2017
(r327274)
@@ -213,6 +213,7 @@ bincvt(char *sysfile, char *outfile, void *img, int fs
tname, sysfile, tname, tname, sysfile, outfile, outfile);
printf("%s", sysbuf);
system(sysbuf);
+   free(outfile);
 
return;
 }
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327279 - head/usr.sbin/fwcontrol

2017-12-27 Thread Warner Losh
Author: imp
Date: Thu Dec 28 05:34:38 2017
New Revision: 327279
URL: https://svnweb.freebsd.org/changeset/base/327279

Log:
  Close fd when we're done dv-sending the file.
  
  CID: 978413

Modified:
  head/usr.sbin/fwcontrol/fwdv.c

Modified: head/usr.sbin/fwcontrol/fwdv.c
==
--- head/usr.sbin/fwcontrol/fwdv.c  Thu Dec 28 05:34:34 2017
(r327278)
+++ head/usr.sbin/fwcontrol/fwdv.c  Thu Dec 28 05:34:38 2017
(r327279)
@@ -417,4 +417,5 @@ send_end:
+ (end.tv_usec - start.tv_usec) * 1e-6;
fprintf(stderr, "%d frames, %.2f secs, %.2f frames/sec\n",
frames, rtime, frames/rtime);
+   close(fd);
 }
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r327280 - in head/sys: arm/allwinner arm/altera/socfpga arm/amlogic/aml8726 arm/annapurna/alpine arm/broadcom/bcm2835 arm/freescale/imx arm/freescale/vybrid arm/lpc arm/mv arm/nvidia/te...

2017-12-27 Thread Emmanuel Vadot
Author: manu
Date: Thu Dec 28 07:31:14 2017
New Revision: 327280
URL: https://svnweb.freebsd.org/changeset/base/327280

Log:
  Revert r327250 as it broke the build for some armv6 kernel and all armv4/5
  
  Reported by:  ian

Modified:
  head/sys/arm/allwinner/files.allwinner
  head/sys/arm/altera/socfpga/files.socfpga
  head/sys/arm/amlogic/aml8726/files.aml8726
  head/sys/arm/annapurna/alpine/files.alpine
  head/sys/arm/broadcom/bcm2835/files.bcm283x
  head/sys/arm/freescale/imx/files.imx5
  head/sys/arm/freescale/imx/files.imx6
  head/sys/arm/freescale/vybrid/files.vybrid
  head/sys/arm/lpc/files.lpc
  head/sys/arm/mv/files.mv
  head/sys/arm/nvidia/tegra124/files.tegra124
  head/sys/arm/qemu/files.qemu
  head/sys/arm/ralink/files.ralink
  head/sys/arm/rockchip/files.rk30xx
  head/sys/arm/samsung/exynos/files.exynos5
  head/sys/arm/ti/files.ti
  head/sys/arm/versatile/files.versatile
  head/sys/arm/xilinx/files.zynq7
  head/sys/conf/files.arm

Modified: head/sys/arm/allwinner/files.allwinner
==
--- head/sys/arm/allwinner/files.allwinner  Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/allwinner/files.allwinner  Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,4 +1,5 @@
 # $FreeBSD$
+kern/kern_clocksource.cstandard
 
 arm/allwinner/a10_ahci.c   optionalahci
 arm/allwinner/a10_codec.c  optionalsound

Modified: head/sys/arm/altera/socfpga/files.socfpga
==
--- head/sys/arm/altera/socfpga/files.socfpga   Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/altera/socfpga/files.socfpga   Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,5 +1,7 @@
 # $FreeBSD$
 
+kern/kern_clocksource.cstandard
+
 arm/altera/socfpga/socfpga_common.cstandard
 arm/altera/socfpga/socfpga_machdep.c   standard
 arm/altera/socfpga/socfpga_manager.c   standard

Modified: head/sys/arm/amlogic/aml8726/files.aml8726
==
--- head/sys/arm/amlogic/aml8726/files.aml8726  Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/amlogic/aml8726/files.aml8726  Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,5 +1,7 @@
 #$FreeBSD$
 
+kern/kern_clocksource.cstandard
+
 arm/amlogic/aml8726/aml8726_l2cache.c  standard
 
 arm/amlogic/aml8726/aml8726_machdep.c  standard

Modified: head/sys/arm/annapurna/alpine/files.alpine
==
--- head/sys/arm/annapurna/alpine/files.alpine  Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/annapurna/alpine/files.alpine  Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,5 +1,7 @@
 # $FreeBSD$
 
+kern/kern_clocksource.cstandard
+
 arm/versatile/sp804.c  standard
 dev/uart/uart_dev_ns8250.c optionaluart
 

Modified: head/sys/arm/broadcom/bcm2835/files.bcm283x
==
--- head/sys/arm/broadcom/bcm2835/files.bcm283x Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/broadcom/bcm2835/files.bcm283x Thu Dec 28 07:31:14 2017
(r327280)
@@ -17,6 +17,8 @@ arm/broadcom/bcm2835/bcm2835_vcio.c   standard
 arm/broadcom/bcm2835/bcm2835_wdog.cstandard
 arm/broadcom/bcm2835/bcm283x_dwc_fdt.c optional dwcotg fdt
 
+kern/kern_clocksource.c standard
+
 dev/mbox/mbox_if.m standard
 
 arm/broadcom/bcm2835/bcm2835_audio.c   optional sound vchiq \

Modified: head/sys/arm/freescale/imx/files.imx5
==
--- head/sys/arm/freescale/imx/files.imx5   Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/freescale/imx/files.imx5   Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,4 +1,5 @@
 # $FreeBSD$
+kern/kern_clocksource.cstandard
 
 # Init
 arm/freescale/imx/imx_common.c standard

Modified: head/sys/arm/freescale/imx/files.imx6
==
--- head/sys/arm/freescale/imx/files.imx6   Thu Dec 28 05:34:38 2017
(r327279)
+++ head/sys/arm/freescale/imx/files.imx6   Thu Dec 28 07:31:14 2017
(r327280)
@@ -1,6 +1,11 @@
 # $FreeBSD$
 
 #
+# Standard ARM support.
+#
+kern/kern_clocksource.cstandard
+
+#
 # Standard imx6 devices and support.
 #
 arm/freescale/fsl_ocotp.c  standard

Modified: head/sys/arm/freescale/vybrid/files.vybrid
==
--- head/sys/arm/freescale/vybrid/files.vybrid
--- head/sbin/dump/main.c   Wed Dec 27 22:01:30 2017(r327252)
+++ head/sbin/dump/main.c   Wed Dec 27 22:18:56 2017(r327253)
@@ -439,8 +439,8 @@ main(int argc, char *argv[])
sync();
sblock = (struct fs *)sblock_buf;
for (i = 0; sblock_try[i] != -1; i++) {
-   sblock->fs_fsize = SBLOCKSIZE; /* needed in bread */
-   bread(sblock_try[i] >> dev_bshift, (char *) sblock, SBLOCKSIZE);
+   sblock->fs_fsize = SBLOCKSIZE; /* needed in blkread */
+   blkread(sblock_try[i]>>dev_bshift, (char *) sblock, SBLOCKSIZE);
if ((sblock->fs_magic == FS_UFS1_MAGIC ||
 (sblock->fs_magic == FS_UFS2_MAGIC &&
  sblock->fs_sblockloc == sblock_try[i])) &&
@@ -556,7 +556,7 @@ main(int argc, char *argv[])
/*
 * Skip directory inodes deleted and maybe reallocated
 */
-   dp = getino(ino, &mode);
+   dp = getinode(ino, &mode);
if (mode != IFDIR)
continue;
(void)dumpino(dp, ino);
@@ -575,7 +575,7 @@ main(int argc, char *argv[])
/*
 * Skip inodes deleted and reallocated as directories.
 */
-   dp = getino(ino, &mode);
+   dp = getinode(ino, &mode);
if (mode == IFDIR)
continue;
(void)dumpino(dp, ino);

Modified: head/sbin/dump/tape.c
==